@@ -13,13 +13,10 @@ import wx
 #import os,h5py
 import numpy as np
 
-try:
-  import glumpy
-  from glumpy.graphics import VertexBuffer
-  import wx.glcanvas
-  from OpenGL.GL import *
-except ImportError as e:
-  print 'ImportError: '+e.message
+import glumpy
+from glumpy.graphics import VertexBuffer
+import wx.glcanvas
+from OpenGL.GL import *
 
 def MplAddColormap(m,lut):
   if type(lut)==dict:
@@ -178,12 +175,12 @@ class GLCanvasImg(wx.glcanvas.GLCanvas):
 
   def OnEraseBackground(self, event):
     """Process the erase background event."""
-    print 'OnEraseBackground'
+    #print 'OnEraseBackground'
     pass # Do nothing, to avoid flashing on MSWin
 
   def OnSize(self, event):
     """Process the resize event."""
-    print 'OnSize'
+    #print 'OnSize'
     if self.GetContext():
             # Make sure the frame is shown before calling SetCurrent.
       self.Show()
@@ -261,36 +258,69 @@ use mouse wheel to zoom in/out the image at a given point
     try:
       glImg=self.glImg
     except AttributeError as e:
-      colRng=(0,10)
       colMap=self.glColBar._filter.colormap
-      self.glImg=glImg=glumpy.image.Image(txrData, colormap=colMap,vmin=colRng[0], vmax=colRng[1])
+      txrRng=self.GetTxrRange()
+      self.glImg=glImg=glumpy.image.Image(txrData, colormap=colMap,vmin=txrRng[0], vmax=txrRng[1])
     else:
       if glImg.data.shape==self.data.shape:
-        glImg.data[:]=self.GetTxrData()
+        glImg.data[:]=txrData[:]
       else:
         self.glImg=glImg=glumpy.image.Image(txrData, colormap=colMap,vmin=glImg._vmin, vmax=glImg._vmax)   
     glImg.update()
 
+  def GetTxrRange(self):
+    txrTrfFunc=self.txrTrfFunc
+    dataRange=self.dataRange
+    if txrTrfFunc==0:
+      return dataRange
+    elif txrTrfFunc==1:
+      return (0,np.log(1+dataRange[1]-dataRange[0]))
+  
+  def AutoRange(self,txrTrfFunc):
+    data=self.data
+    self.txrTrfFunc=txrTrfFunc
+    if txrTrfFunc==0:
+      avg=np.average(data); std=np.std(data)
+      vmin=np.min(data);vmax=np.max(data)
+      vmin=max(vmin,avg-3*std);vmax=min(vmax,avg+3*std)      
+    elif txrTrfFunc==1:
+      vmin=np.min(data)
+      vmax=np.average(data)
+    self.dataRange=(vmin,vmax)
+
   def GetTxrData(self):
     data=self.data
-    #frm=data[...].astype(np.float32)     
-    txrData=5.*np.log(data[...].astype(np.float32)+1.)
+    try:
+      txrTrfFunc=self.txrTrfFunc
+    except AttributeError as e:
+      self.AutoRange(1)     
+      txrTrfFunc=self.txrTrfFunc
+
+    if txrTrfFunc==0:
+      if data.dtype==np.float32:
+        txrData=data
+      else:
+        txrData=data[...].astype(np.float32)
+    elif txrTrfFunc==1:
+      ofs=1.-self.dataRange[0]
+      txrData=np.log(data[...].astype(np.float32)+ofs)
     return txrData
   
   def InitGL(self):
     """Initialize OpenGL for use in the window."""
-    print 'InitGL'
+    #print 'InitGL'
     glClearColor(.2, .2, .2, 1)
     colMap=glumpy.colormap.Hot
     txrColBar=np.linspace(0.,1., 256).astype(np.float32)
     self.glColBar=glumpy.image.Image(txrColBar, colormap=colMap,vmin=0, vmax=1)
+   
     self.UpdateImg()
     self.imgCoord=np.array([-.49,0,.49,1,-.49,0,.49,1])#xmin,xmax,umin,umax,ymin,ymax,vmin,vmax    
     pass
 
   def Reshape(self, width, height):
     """Reshape the OpenGL viewport based on the dimensions of the window."""
-    print 'Reshape'
+    #print 'Reshape'
     glViewport(0, 0, width, height)
 
     glMatrixMode(GL_PROJECTION)
@@ -303,12 +333,19 @@ use mouse wheel to zoom in/out the image at a given point
 class DlgColBarSetup(wx.Dialog):
   def __init__(self,parent):
     wx.Dialog.__init__(self,parent,-1,'Colormap Setup')
-    glImg=parent.glImg
+    #glImg=parent.glImg
+    #glColBar=parent.glColBar
+    dataRange=parent.dataRange   
     txtVMin=wx.StaticText(self,-1,'vmin')
     txtVMax=wx.StaticText(self,-1,'vmax')
-    txtColMap=wx.StaticText(self,-1,'colormap')
-    self.edVMin=edVMin=wx.TextCtrl(self,-1,'%g'%glImg._vmin,style=wx.TE_PROCESS_ENTER)
-    self.edVMax=edVMax=wx.TextCtrl(self,-1,'%g'%glImg._vmax,style=wx.TE_PROCESS_ENTER)
+    txtColMap=wx.StaticText(self,-1,'colormap')   
+    self.edVMin=edVMin=wx.TextCtrl(self,-1,'%g'%dataRange[0],style=wx.TE_PROCESS_ENTER)
+    self.edVMax=edVMax=wx.TextCtrl(self,-1,'%g'%dataRange[1],style=wx.TE_PROCESS_ENTER)
+
+    txtTxrFunc=wx.StaticText(self,-1,'function')   
+    self.cbtxrFunc=cbtxrFunc=wx.ComboBox(self, -1, choices=('linear','logarithmic'), style=wx.CB_READONLY)
+    cbtxrFunc.SetSelection(parent.txrTrfFunc)
+    
     colMapLst=[]
     #adding all existing colormaps
     #MplAddAllColormaps()
@@ -334,13 +371,16 @@ class DlgColBarSetup(wx.Dialog):
         colMapLst.append(k)
 
     self.cbColMap=cbColMap=wx.ComboBox(self, -1, choices=colMapLst, style=wx.CB_READONLY)
+    cbColMap.Value=parent.glImg._filter.colormap.name
     
     sizer=wx.BoxSizer(wx.VERTICAL)
-    fgs=wx.FlexGridSizer(3,2,5,5)
+    fgs=wx.FlexGridSizer(4,2,5,5)
     fgs.Add(txtVMin,0,wx.ALIGN_RIGHT)
     fgs.Add(edVMin,0,wx.EXPAND)
     fgs.Add(txtVMax,0,wx.ALIGN_RIGHT)
     fgs.Add(edVMax,0,wx.EXPAND)
+    fgs.Add(txtTxrFunc,0,wx.ALIGN_RIGHT)
+    fgs.Add(cbtxrFunc,0,wx.EXPAND)
     fgs.Add(txtColMap,0,wx.ALIGN_RIGHT)
     fgs.Add(cbColMap,0,wx.EXPAND)
     sizer.Add(fgs,0,wx.EXPAND|wx.ALL,5)
@@ -357,28 +397,38 @@ class DlgColBarSetup(wx.Dialog):
     #self.Bind(wx.EVT_TEXT_ENTER, self.OnModify, edVMax)
     self.Bind(wx.EVT_TEXT, self.OnModify, edVMin)
     self.Bind(wx.EVT_TEXT, self.OnModify, edVMax)
+    self.Bind(wx.EVT_COMBOBOX, self.OnModify, cbtxrFunc)
     self.Bind(wx.EVT_COMBOBOX, self.OnModify, cbColMap)
 
     self.SetSizer(sizer)
     sizer.Fit(self)
 
   def OnModify(self, event):
-    print 'OnModify'
+    #print 'OnModify'
     parent=self.GetParent()
     glImg=parent.glImg
-    glImg._vmin=float(self.edVMin.Value)
-    glImg._vmax=float(self.edVMax.Value)
+    glColBar=parent.glColBar
+
     v=self.cbColMap.Value
-    if v:
+    if v!=glImg._filter.colormap.name:
       cmap=getattr(glumpy.colormap,v)
       glImg._filter.colormap=cmap
       glImg._filter.build()
-      cbar=parent.glColBar
-      cbar._filter.colormap=cmap
-      cbar._filter.build()
-      cbar.update()
-
-    glImg.update()
+      glColBar._filter.colormap=cmap
+      glColBar._filter.build()
+      glColBar.update()   
+    
+    parent.dataRange=(float(self.edVMin.Value),float(self.edVMax.Value))
+    v=self.cbtxrFunc.GetCurrentSelection()
+    if v==1 or v!=parent.txrTrfFunc:
+      parent.txrTrfFunc=v  
+      txrRange=parent.GetTxrRange()   
+      glImg._vmin, glImg._vmax = txrRange
+      parent.UpdateImg()
+    else:
+      txrRange=parent.GetTxrRange()   
+      glImg._vmin, glImg._vmax = txrRange
+      glImg.update()
     parent.Refresh(False)
     if event.GetId()==wx.ID_OK:
       event.Skip()#do not consume (use event to close the window and sent return code)
